@@ -6,7 +6,8 @@ descr_out <- function(descr, ret_type = "html") {
 
   ## if there is a data description and we want html output
   if (ret_type == "html") {
-    markdown::markdownToHTML(text = descr, stylesheet = "")
+    # markdown::markdownToHTML(text = descr, stylesheet = "", fragment.only = TRUE)
+    markdown::mark_html(text = descr, template = FALSE, meta = list(css = ""))
   } else {
     descr
   }
@@ -188,4 +189,4 @@ load_user_data <- function(fname, uFile, ext, header = TRUE,
   }
   r_info[[glue("{objname}_lcmd")]] <- cmd
   r_info[["datasetlist"]] <- c(objname, r_info[["datasetlist"]]) %>% unique()
-}
\ No newline at end of file
+}
